==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebPinColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnEventArgsDetailDescriptionMetadata } from "./WebPinColumnEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDescription } from "./WebPinColumnEventArgsDescription";
/**
 * @hidden
 */
var WebPinColumnEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPinColumnEventArgsDescriptionMetadata, _super);
    function WebPinColumnEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnEventArgsDescriptionMetadata.b = function (a) {
        if (WebPinColumnEventArgsDescriptionMetadata.a == null) {
            WebPinColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnEventArgsDescriptionMetadata.c(WebPinColumnEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPinColumnEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPinColumnEventArgsDescriptionMetadata.a);
        WebPinColumnEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPinColumnEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PinColumnEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("Detail", "ExportedType:WebPinColumnEventArgsDetail");
    };
    WebPinColumnEventArgsDescriptionMetadata.d = function (a) {
        WebPinColumnEventArgsDescriptionMetadata.b(a);
        a.aa("WebPinColumnEventArgs", function () { return new WebPinColumnEventArgsDescription(); });
        a.z("WebPinColumnEventArgs", WebPinColumnEventArgsDescriptionMetadata.a);
    };
    WebPinColumnEventArgsDescriptionMetadata.$t = markType(WebPinColumnEventArgsDescriptionMetadata, 'WebPinColumnEventArgsDescriptionMetadata');
    WebPinColumnEventArgsDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDescriptionMetadata;
}(Base));
export { WebPinColumnEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPinColumnEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebPinColumnEventArgsDetailDescriptionMetadata } from "./WebPinColumnEventArgsDetailDescriptionMetadata";
import { WebPinColumnEventArgsDescription } from "./WebPinColumnEventArgsDescription";
/**
 * @hidden
 */
var WebPinColumnEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPinColumnEventArgsDescriptionMetadata, _super);
    function WebPinColumnEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnEventArgsDescriptionMetadata.b = function (a) {
        if (WebPinColumnEventArgsDescriptionMetadata.a == null) {
            WebPinColumnEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnEventArgsDescriptionMetadata.c(WebPinColumnEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPinColumnEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPinColumnEventArgsDescriptionMetadata.a);
        WebPinColumnEventArgsDetailDescriptionMetadata.d(a);
    };
    WebPinColumnEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PinColumnEventArgs");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Detail", "ExportedType:WebPinColumnEventArgsDetail");
    };
    WebPinColumnEventArgsDescriptionMetadata.d = function (a) {
        WebPinColumnEventArgsDescriptionMetadata.b(a);
        a.ac("WebPinColumnEventArgs", function () { return new WebPinColumnEventArgsDescription(); });
        a.ab("WebPinColumnEventArgs", WebPinColumnEventArgsDescriptionMetadata.a);
    };
    WebPinColumnEventArgsDescriptionMetadata.$t = markType(WebPinColumnEventArgsDescriptionMetadata, 'WebPinColumnEventArgsDescriptionMetadata');
    WebPinColumnEventArgsDescriptionMetadata.a = null;
    return WebPinColumnEventArgsDescriptionMetadata;
}(Base));
export { WebPinColumnEventArgsDescriptionMetadata };
